@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# $Id: install.sh 1989 2008-06-22 20:17:59Z bruno $
+# $Id: install.sh 3173 2013-07-29 07:08:58Z bruno $
 #
 
 if [ ! -f "mindi" ] ; then
@@ -37,10 +37,11 @@ if uname -a | grep Knoppix > /dev/null || [ -e "/ramdisk/usr" ] ; then
     export PATH=/ramdisk/usr/sbin:/ramdisk/usr/bin:/$PATH
 fi
 
-MINDIVER=2.0.5
-MINDIREV=2153
+MINDIVER=2.1.7
+MINDIREV=3184
+VERSTR=${MINDIVER}-r${MINDIREV}
 ARCH=`/bin/uname -m`
-echo "mindi ${MINDIVER}-r${MINDIREV} will be installed under $local"
+echo "mindi $VERSTR will be installed under $local"
 
 if [ _"$CACHEDIR" = _"" ]; then
 	CACHEDIR=$local/var/cache/mindi
@@ -68,37 +69,46 @@ else
 fi
 
 echo "Creating target directories ..."
-install -m 755 -d $conf $locallib/mindi $MANDIR $local/sbin $CACHEDIR
+install -m 755 -d $conf $locallib/mindi $MANDIR $local/sbin $CACHEDIR $conf/deplist.d
 
 echo "Copying files ..."
 cp -af rootfs $locallib/mindi
 chmod 755 $locallib/mindi/rootfs/sbin/*
 install -m 755 analyze-my-lvm $locallib/mindi
 install -m 644 msg-txt dev.tgz $locallib/mindi
-install -m 644 deplist.txt udev.files proliant.files $conf
+install -m 644 deplist.txt mindi.conf README.bootparam README.pxe $conf
+for f in deplist.d/*.conf; do
+	install -m 644 $f $conf/deplist.d
+done
 
 # Substitute variables for mindi
 sed -e "s~^MINDI_PREFIX=XXX~MINDI_PREFIX=$sublocal~" -e "s~^MINDI_CONF=YYY~MINDI_CONF=$subconf~" -e "s~^MINDI_LIB=LLL~MINDI_LIB=$sublocallib~" mindi > $local/sbin/mindi
-sed -e "s~= "YYY"~= "$subconf"~" mindi-bkphw > $local/sbin/mindi-bkphw
-chmod 755 $local/sbin/mindi $local/sbin/mindi-bkphw
-install -m 755 parted2fdisk.pl $local/sbin
-
+chmod 755 $local/sbin/mindi
 install -m 644 mindi.8 $MANDIR
-#install -m 644 ChangeLog COPYING README README.busybox README.ia64 README.pxe TODO INSTALL svn.log $DOCDIR
+
+# Manage perl script man pages
+for s in mindi-bkphw mindi-get-perl-modules parted2fdisk.pl; do
+	install -m 755 $s $local/sbin
+	pod2man -c "$s a MondoRescue tool" --section=8 --release="$VERSTR" $local/sbin/$s > $s.8
+	install -m 644 $s.8 $MANDIR
+	# Generate the list of perl modules needed at restore time for mindi
+	cat > $conf/perl-scripts << EOF
+$sublocal/sbin/$s
+EOF
+done
+(cd $MANDIR ; ln -s parted2fdisk.pl.8 parted2fdisk.9)
 
 if [ "_$PREFIX" = "_" ] && [ ! -f $locallib/mindi/rootfs/bin/busybox ]; then
-		echo "WARNING: no busybox found, mindi will not work on this arch ($ARCH)"
+	echo "WARNING: no busybox found, mindi will not work on this arch ($ARCH)"
 fi
 
 # Managing parted2fdisk
 if [ "$ARCH" = "ia64" ] ; then
 	(cd $local/sbin && ln -sf parted2fdisk.pl parted2fdisk)
 	install -s -m 755 $local/sbin/parted2fdisk.pl $locallib/mindi/rootfs/sbin/parted2fdisk
-	# Try to avoid the need ot additional perl modules at the moment
-	perl -pi -e 's/use strict;//' $locallib/mindi/rootfs/sbin/parted2fdisk
 else
 	# FHS requires fdisk under /sbin
-	(cd $local/sbin && ln -sf /sbin/fdisk parted2fdisk)
+	(cd $local/sbin && ln -sf ../../sbin/fdisk parted2fdisk)
 	echo "Symlinking fdisk to parted2fdisk"
 	( cd $locallib/mindi/rootfs/sbin && ln -sf fdisk parted2fdisk)
 fi
