@@ -1,24 +1,97 @@
 #!/usr/bin/perl -w
 #
-# $Id: parted2fdisk.pl 1857 2008-01-11 14:28:40Z bruno $
+# $Id: parted2fdisk.pl 3143 2013-06-14 04:06:09Z bruno $
 #
 # parted2fdisk: fdisk like interface for parted 
 # [developped for mindi/mondo http://www.mondorescue.org]
 #
 # Aims to be architecture independant (i386/ia64)
-# Tested on RHAS 2.1 ia64 - Mandrake 9.0 ia64 - RHAS 3.0 ia64 - SLES 10
+# Tested on ia64 with RHAS 2.1 - Mandrake 9.0 - RHEL 3.0 - SLES 10
 #
-# (c) Bruno Cornec <Bruno.Cornec@hp.com>
-# Licensed under the GPL
+# Copyright B. Cornec 2000-2013
+# Provided under the GPL v2
 
 use strict;
 
+
+=pod
+
+=head1 NAME
+
+parted2fdisk is a fdisk lie command using parted internally.
+
+=head1 DESCRIPTION
+
+parted2fdisk behaves like a fdisk command, but dialog internally with parted in order to manipulate partiion tables, which allow it to support GPT partition format as well as MBR, contrary to fdisk. It aimed at providing compatible external interface wti fdisk. Developed initialy for ia64 Linux, but is also useful now on x86 systems using GPT partition format (for large HDDs).
+
+=head1 SYNOPSIS
+
+parted2fdisk -s partition
+parted2fdisk -l device
+parted2fdisk [-n] device
+
+=head1 OPTIONS
+
+=over 4
+
+=item B<-s>
+
+Print the size (in blocks) of the given partition.
+
+=item B<-n>
+
+Fake mode. Doesn't pass the commands just simulate.
+
+=item B<-l>
+
+List the partition tables for the specified device and then exit.
+
+=item B<no option>
+
+Allow the creation and manipulation of partition tables.
+
+=back
+
+=head1 ARGUMENTS
+
+=over 4
+
+=item B<partition> 
+
+partition device file (only used with -s option).
+
+=item B<device> 
+
+device file to work on.
+
+=back
+
+=head1 WEB SITES
+
+The main Web site of the project is available at L<http://www.mondorescue.org>. Bug reports should be filled using the trac instance of the project at L<http://trac.mondorescue.org/>.
+
+=head1 USER MAILING LIST
+
+For community exchanges around MondoRescue please use the list L<http://sourceforge.net/mailarchive/forum.php?forum_name=mondo-devel>
+
+=head1 AUTHORS
+
+The MondoRescue team lead by Bruno Cornec L<mailto:bruno@mondorescue.org>.
+
+=head1 COPYRIGHT
+
+MondoRescue is distributed under the GPL v2.0 license or later,
+described in the file C<COPYING> included with the distribution.
+
+=cut
+
+
 $ENV{LANG} = "C";
 $ENV{LANGUAGE} = "C";
 $ENV{LC_ALL} = "C";
 
 # Log 
-my $flog = "/tmp/parted2fdisk.log";
+my $flog = "/var/log/parted2fdisk.log";
 open(FLOG, "> $flog") || die "Unable to open $flog";
 
 my $fdisk = "/sbin/fdisk";
@@ -39,6 +112,9 @@ my $arch;
 my $fake = 0;
 my $mega = 1048576;
 
+# Immediate flushing to avoids read error from mondorestore in log files
+$| = 1;
+
 # Determine on which arch we're running
 if (defined ($ENV{ARCH})) {
 	$arch = $ENV{ARCH};
@@ -73,9 +149,11 @@ my %pid = (	"FAT" => "6",
 		"fat16" => "e",
 		"ext2" => "83",
 		"ext3" => "83",
+		"ext4" => "83",
+		"xfs" => "83",
 		"reiserfs" => "83",
 		"linux-swap" => "82",
-		"LVM" => "8e",
+		"lvm" => "8e",
 		"" => "",
 	);
 my %pnum;
@@ -139,8 +217,8 @@ if ($arch =~ /^ia64/) {
 			while ($i = <STDIN>) {
 				if ($i =~ /^p$/) {
 					fdisk_list($device,undef,\%start,\%end, 1);
-				}
-				elsif ($i =~ /^n$/) {
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
+				} elsif ($i =~ /^n$/) {
 					fdisk_list($device,undef,\%start,\%end, 0);
 					if ($type ne "gpt") {
 						print FLOG "Forcing GPT type of disk label\n";
@@ -208,8 +286,8 @@ if ($arch =~ /^ia64/) {
 					$end = $cylend * $un / $mega;
 					print FLOG "n $l $part $cylstart $cylend => mkpart primary $start $end\n";
 					system "$parted -s $device mkpart primary ext2 $start $end\n" if ($fake == 0);
-				}
-				elsif ($i =~ /^d$/) {
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
+				} elsif ($i =~ /^d$/) {
 					$part = <STDIN>;
 					if (not (defined $part)) {
 						print FLOG "no partition given for deletion... skipping\n";
@@ -219,18 +297,23 @@ if ($arch =~ /^ia64/) {
 					print FLOG "d $part => rm $part\n";
 					system "$parted -s $device rm $part\n" if ($fake == 0);
 					get_parted($device,undef,\%start,\%end,undef);
-				}
-				elsif ($i =~ /^w$/) {
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
+				} elsif ($i =~ /^w$/) {
 					print FLOG "w => quit\n";
-				}
-				elsif ($i =~ /^t$/) {
+				} elsif ($i =~ /^t$/) {
 					$part = <STDIN>;
 					if (not (defined $part)) {
 						print FLOG "no partition given for tagging... skipping\n";
 						next;
 					}
 					chomp($part);
-					$l = <STDIN>;
+					# If no partition number given it's 1, and we received the type
+					if ($part !~ /\d+/) {
+						$l = $part;
+						$part = 1 
+					} else {
+						$l = <STDIN>;
+					}
 					if (not (defined $l)) {
 						print FLOG "no type given for tagging partition $part... skipping\n";
 						next;
@@ -240,24 +323,35 @@ if ($arch =~ /^ia64/) {
 						print FLOG "no partition number given for $l... please report to the author\n";
 						next;
 					}
-					print FLOG "t $part $l => mkfs $part $pnum{$l}\n";
-					system "$parted -s $device mkfs $part $pnum{$l}\n" if ($fake == 0);
-				}
-				elsif ($i =~ /^a$/) {
+
+					if ($pnum{$l} eq "lvm") {
+						# In that case this is a flag set, not a mkfs
+						print FLOG "t $part $l => set $part $pnum{$l} on\n";
+						system "$parted -s $device set $part $pnum{$l} on\n" if ($fake == 0);
+					} else {
+						print FLOG "t $part $l => mkfs $part $pnum{$l}\n";
+						system "$parted -s $device mkfs $part $pnum{$l}\n" if ($fake == 0);
+					}
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
+				} elsif ($i =~ /^a$/) {
 					$part = <STDIN>;
 					if (not (defined $part)) {
 						print FLOG "no partition given for tagging... skipping\n";
 						next;
 					}
 					chomp($part);
+
+					# Partition shouldn't be negative or null. Then take the first one.
+					$part = 1 if ($part le 0);
+
 					print FLOG "a $part => set $part boot on\n";
 					system "$parted -s $device set $part boot on\n" if ($fake == 0);
-				}
-				elsif ($i =~ /^q$/) {
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
+				} elsif ($i =~ /^q$/) {
 					print FLOG "q => quit\n";
-				}
-				else {
+				} else {
 					print FLOG "Unknown command: $i\n";
+					print "command (m for help) send back to fake fdisk for mondorestore\n";
 					next;
 				}
 					
@@ -334,9 +428,11 @@ my $n;
 my %cmt = (	"FAT" => "FAT",
 		"ext2" => "Linux",
 		"ext3" => "Linux",
+		"ext4" => "Linux",
+		"xfs" => "Linux",
 		"reiserfs" => "Linux",
 		"linux-swap" => "Linux swap",
-		"LVM" => "Linux LVM",
+		"lvm" => "Linux LVM",
 		"fat16" => "fat16",
 		"fat32" => "fat32",
 		"" => "Linux",
